Module cli

Module cli 

Command-line argument parsing and conversion into config::AppConfig. Parse CLI arguments and convert them into runtime configuration values.

Structs

BilibiliArgs
Bilibili CLI task arguments.
Cli
Top-level command-line interface definition.
DouyinArgs
Douyin CLI task arguments.
KuaishouArgs
Kuaishou CLI task arguments.
RunArgs
Arguments for the run subcommand.
ServeArgs
Arguments for the serve subcommand.
TwitterArgs
Twitter/X CLI task arguments.
XiaohongshuArgs
Xiaohongshu CLI task arguments.

Enums

BilibiliCommand
Bilibili tasks exposed through the CLI.
Command
Supported CLI subcommands.
DouyinCommand
Douyin tasks exposed through the CLI.
KuaishouCommand
Kuaishou tasks exposed through the CLI.
RunTaskArgs
Nested tasks for the run subcommand.
TwitterCommand
Twitter/X tasks exposed through the CLI.
XiaohongshuCommand
Xiaohongshu tasks exposed through the CLI.

Functions

parse_env
Parse CLI arguments from the current process environment.
parse_from
Parse CLI arguments from a custom iterator.
try_parse_env
Parse CLI arguments after resolving values from process env and layered dotenv files.