Command-line argument parsing and conversion into config::AppConfig.
Parse CLI arguments and convert them into runtime configuration values.
Structs
- Bilibili
Args - Bilibili CLI task arguments.
- Cli
- Top-level command-line interface definition.
- Douyin
Args - Douyin CLI task arguments.
- Kuaishou
Args - Kuaishou CLI task arguments.
- RunArgs
- Arguments for the
runsubcommand. - Serve
Args - Arguments for the
servesubcommand. - Twitter
Args - Twitter/X CLI task arguments.
- Xiaohongshu
Args - Xiaohongshu CLI task arguments.
Enums
- Bilibili
Command - Bilibili tasks exposed through the CLI.
- Command
- Supported CLI subcommands.
- Douyin
Command - Douyin tasks exposed through the CLI.
- Kuaishou
Command - Kuaishou tasks exposed through the CLI.
- RunTask
Args - Nested tasks for the
runsubcommand. - Twitter
Command - Twitter/X tasks exposed through the CLI.
- Xiaohongshu
Command - Xiaohongshu tasks exposed through the CLI.
Functions
- parse_
env - Parse CLI arguments from the current process environment.
- parse_
from - Parse CLI arguments from a custom iterator.
- try_
parse_ env - Parse CLI arguments after resolving values from process env and layered dotenv files.